(vl-load-com) ; included to allow for AutoCAD compatibility

; CCL-RenameThisLayer
; Renames the given layer
; requires the layer object to rename & the target layer name
; Returns 0 if it fails, 1 if it succeeds

(defun CCL-RenameThisLayer (oLayer NewLayName / flag oldLayerName oRet)
	(setq flag 0)
	(setq oldLayerName (vla-get-name oLayer))
	(princ (Strcat "\nRenaming " oldLayerName " -> " NewLayName ))
	(setq oRet (vl-catch-all-apply 'vla-put-name (list oLayer NewLayName)))
		(cond ((and (vl-catch-all-error-p oRet)	(wcmatch (vl-catch-all-error-message oret) "*Duplicate Record name*"))
						(Princ "\nFAILED, target layer name already exists")
					)
					((vl-catch-all-error-p oRet)
						(Princ "\nFAILED, an error occured")
					)
					(T (Princ "\nOK") (setq flag 1))
		)
flag
)

; CCL-LAYRENAME
; Renames layers based on search string and replacement string
; replacing the search string with replacement in each place it's found.
; Rename can be either:
; - An exact match of the search string with the layer name
; - A partial match of the search string with the layer name
; NOTE. You can't (currently) use wildcard matching in the search string
;
; e.g.
; EXACT MATCH
;(CCL-LAYRENAME "C-PVMT-CONC-EX" "C-PAVE-CONC-EX" T)
; Renaming C-PVMT-CONC-EX -> C-PAVE-CONC-EX
; OK
; 1
; 
; PARTIAL MATCH
; (CCL-LAYRENAME "C-PVMT-CONC-EX" "C-PAVE-CONC-EX" nil)
; Renaming C-PVMT-CONC-EX -> C-PAVE-CONC-EX
;	OK
;	Renaming C-PVMT-CONC-EX-HATCH -> C-PAVE-CONC-EX-HATCH
;	OK
;	Renaming C-PVMT-CONC-EX-NPLT -> C-PAVE-CONC-EX-NPLT
;	OK
;	Renaming C-PVMT-CONC-EX-TEXT -> C-PAVE-CONC-EX-TEXT
;	OK
;	4

(defun CCL-LayRename (oldstring newstring exact / case oDoc oLay NoLayers cnt num oThisLayer LayerName NeLayerName oRet)
	(setq case nil) ; if T then string comparison is case sensitive
	(setq oDoc (vla-get-activedocument (vlax-get-acad-object))); retrieve current doc
	(setq oLay (vla-get-Layers odoc))
	(setq NoLayers (vla-get-count olay))
	(setq cnt 1 num 0)
	(vla-EndUndoMark oDoc)
	(vla-StartUndoMark oDoc)
	(cond
		(exact
			(cond 
				((not (vl-catch-all-error-p (setq oThisLayer (vl-catch-all-apply 'vla-item (list olay oldstring)))))
				 (setq num (CCL-RenameThisLayer oThisLayer newstring))
				)
			)
		)
		(T
			(repeat (1- NoLayers)
				(setq oThisLayer (vla-item oLay cnt))
				(setq LayerName (vla-get-name oThisLayer))
				(cond
					((not (acet-str-equal LayerName (setq NewLayName (acet-str-replace oldstring newstring LayerName (not case))) case))
						(setq num (+ num (CCL-RenameThisLayer oThisLayer NewLayName)))
					)
				)
				(setq cnt (1+ cnt))
			)
		)
	)
	(vla-EndUndoMark oDoc)
	(Princ "\n")
num
)